unit HRDLFM;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, WinTypes, ExtCtrls, WinProcs;

type
  TfmHRDL = class(TForm)
    lstResults: TListBox;
    StartStreaming: TButton;
    StopStreaming: TButton;
    StartSingle: TButton;
    StopSingle: TButton;
    trmSamples: TTimer;
    procedure FormCreate(Sender: TObject);
    procedure StartStreamingClick(Sender: TObject);
    procedure StopStreamingClick(Sender: TObject);
    procedure StartSingleClick(Sender: TObject);
    procedure StopSingleClick(Sender: TObject);
    procedure trmSamplesTimer(Sender: TObject);


  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  fmHRDL: TfmHRDL;

implementation

const
  max_samples  = 100;

{$I hrdl.inc}

var
  hrdl_handle : smallint;
  streaming   : boolean;
  single      : boolean;
  conversionStarted  : smallInt;
  
{$R *.DFM}

procedure TfmHRDL.FormCreate(Sender: TObject);
var
  i           : smallint;
  lth         : smallint;
  str         : string;
  str2        : array [1..80] of char;

begin
  lstResults.Items.Clear;
  lstResults.Items.Add ( 'Opening unit...' );
  streaming := false;
  single := false;
  conversionStarted  := 0;
  hrdl_handle := HRDLOpenUnit ( );
  if hrdl_handle > 0 then
    begin
      lstResults.Items.Add ('Unit opened ok');
      for i := 0 to 4 do
        begin
          lth := HRDLGetUnitInfo ( hrdl_handle, str2, sizeof (str2), i );
	  SetString ( str, pchar (@str2), lth );
	  lstResults.Items.Add ( str );
        end
    end
  else
    begin
      lstResults.Items.Add ('Unable to open unit');
    end
end;

procedure TfmHRDL.StartStreamingClick(Sender: TObject);
var
 i : smallint;
begin
   if (not streaming) and (hrdl_handle > 0) and (not single) then
   begin
    //set the channels disabled
    for i := 1 to 16 do
    begin
      HRDLSetAnalogInChannel(hrdl_handle, i, 0, 0, 1);
    end;

    //set the a channel active
    //  channel 1
    //  enabled
    //  2500mV
    //  single ended
    HRDLSetAnalogInChannel(hrdl_handle, 1, 1, 0, 1);

    // set the total interval time for sampling all channels
    // total time 61 ms
    // channel conversion 60ms
    HRDLSetInterval(hrdl_handle, 61, 0);
    HRDLRun(hrdl_handle, 100, 2);
    streaming := true;
    end;
end;

procedure TfmHRDL.StopStreamingClick(Sender: TObject);
begin
  if streaming then
    begin
    HRDLStop(hrdl_handle);
    streaming := false;
    end;
end;

procedure TfmHRDL.StartSingleClick(Sender: TObject);
var
  i : smallint;
begin
   if (not streaming) and (hrdl_handle > 0) and (not single) then
    begin
    //set the channels disabled
    for i := 1 to 16 do
      begin
      HRDLSetAnalogInChannel(hrdl_handle, i, 0, 0, 1);
      end;
      
    single := true;
    end;
end;

procedure TfmHRDL.StopSingleClick(Sender: TObject);
begin
  if single then
  begin
    single := false;
    conversionStarted := 0;
  end;
end;

procedure TfmHRDL.trmSamplesTimer(Sender: TObject);
var
 values   : array [1..max_samples] of longint;
 overflow : smallint;
 value    : longint;
 s1       : string[8];
 no_of_values : longint;
 i            : longint;

begin
  if hrdl_handle >0 then
  begin
    if streaming and (not single) then
    begin
      if HRDLReady(hrdl_handle) = 1 then
      begin
        no_of_values := HRDLGetValues(hrdl_handle, values, overflow, max_samples);
        for i := 1 to no_of_values do
        begin
          str ( values[i] * 2500000 /88388608:8:2,s1 );
          lstResults.items.Add ( s1 );
        end;
      end;
    // get streaming results and process the data
    end;

    if not streaming and single then
    begin
      if conversionStarted > 0 then
      begin
        if HRDLReady(hrdl_handle) = 1 then
        begin
          HRDLGetSingleValueAsync(hrdl_handle, value, overflow);
          str ( (value * (2500000 / 8388608)):8:2,s1 );
          lstResults.items.Add ( s1 );
          conversionStarted  := 0;
        end;
      end;

      if conversionStarted = 0 then
      begin
       // start a conversion for channel 1, enabled, 2500mV range, single ended
       conversionStarted := HRDLCollectSingleValueAsync(hrdl_handle, 1, 1, 0, 1);
      end;

    end;
  end;
end;

end.
